package com.cmx.wanhui.activity

import android.Manifest
import android.content.Context
import android.content.Intent
import android.content.pm.PackageManager
import android.os.Bundle
import android.text.TextUtils
import android.util.Log
import android.view.View
import android.view.inputmethod.InputMethodManager
import androidx.core.app.ActivityCompat
import com.cmx.wanhui.R
import com.cmx.wanhui.constant.Events
import com.cmx.wanhui.model.LoginBean
import com.cmx.wanhui.model.LoginRes
import com.cmx.wanhui.retrofit.RetrofitAPIManager
import com.cmx.wanhui.utils.MyUtils.setAndroidNativeLightStatusBar
import com.cmx.wanhui.utils.MyUtils.setFullscreen
import com.cmx.wanhui.utils.SpUtils
import com.cmx.wanhui.utils.SpUtils.putString
import com.cmx.wanhui.view.ConfirmDialog
import com.lsxiao.apollo.core.Apollo
import es.dmoral.toasty.Toasty
import kotlinx.android.synthetic.main.activity_login.btn_login
import kotlinx.android.synthetic.main.activity_login.edt_password
import kotlinx.android.synthetic.main.activity_login.edt_username
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class LoginActivity : BaseActivity() {

    private val REQUIRED_PERMISSION_LIST = arrayOf(Manifest.permission.WRITE_EXTERNAL_STORAGE, Manifest.permission.CAMERA)
    private val REQUEST_PERMISSION_CODE = 99
    private var allPermission = true


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_login)
        setFullscreen(this, true, true)
        setAndroidNativeLightStatusBar(this, true)
        checkAllPermission()
        btn_login!!.setOnClickListener(View.OnClickListener {
            if (TextUtils.isEmpty(edt_username!!.text.toString().trim { it <= ' ' })) {
                Toasty.info(this, "请输入用户名").show()
                return@OnClickListener
            }
            if (TextUtils.isEmpty(edt_password.text.toString().trim { it <= ' ' })) {
                Toasty.info(this, "请输入密码").show()
                return@OnClickListener
            }
            toLogin()
        })
    }


    /**
     * 权限检查
     */
    private fun checkAllPermission() {
        ActivityCompat.requestPermissions(this, REQUIRED_PERMISSION_LIST, REQUEST_PERMISSION_CODE)
    }

    override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String?>, grantResults: IntArray) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
        if (requestCode == REQUEST_PERMISSION_CODE) {
            for (i in grantResults.indices.reversed()) {
                if (grantResults[i] != PackageManager.PERMISSION_GRANTED) {
                    allPermission = false
                }
            }
            if (!allPermission) {
                Toasty.info(this, "权限已拒绝，请手动开启!").show()
                finish()
            }
        }
    }


    /**
     * 登录
     */
    private fun toLogin() {
        showDialog()
        val LoginBean = LoginBean()
        LoginBean.username = edt_username.text.toString().trim()
        LoginBean.password = edt_password.text.toString().trim()
        val call = RetrofitAPIManager.provideClientApi().login(LoginBean)
        call!!.enqueue(object : Callback<LoginRes?> {
            override fun onResponse(call: Call<LoginRes?>, response: Response<LoginRes?>) {
                disDialog()
                if (response.isSuccessful && response.body()!!.code == 0) {
                    putString(this@LoginActivity, "token", response.body()!!.access_token)
                    putString(this@LoginActivity, "admin", response.body()!!.is_admin)
                    putString(this@LoginActivity, "sign", response.body()!!.sign)
                    val intent = Intent(this@LoginActivity, MainActivity::class.java)
                    startActivity(intent)
                    finish()
                } else {
                    if (null != response.body() && null != response.body()!!.message) {
                        Toasty.error(this@LoginActivity, response.body()!!.message!!).show()
                    } else {
                        Toasty.error(this@LoginActivity, "登录失败").show()
                    }
                }
            }

            override fun onFailure(call: Call<LoginRes?>, t: Throwable) {
                disDialog()
                Toasty.info(this@LoginActivity, "登录失败").show()
            }
        })
    }


    override fun onBackPressed() {
        ConfirmDialog(this, object : ConfirmDialog.IBack {
            override fun confirmBack() {
                finish()
            }

            override fun cancelBack() {
            }
        }).show()
    }

}