package com.cmx.wanhui.activity

import android.content.Intent
import android.os.Build
import android.os.Bundle
import android.util.Log
import android.view.View
import androidx.annotation.RequiresApi
import androidx.navigation.NavController
import androidx.navigation.Navigation
import androidx.navigation.ui.NavigationUI
import cn.jpush.android.api.JPushInterface
import com.cmx.wanhui.R
import com.cmx.wanhui.constant.Events
import com.cmx.wanhui.utils.SpUtils
import com.cmx.wanhui.view.ConfirmDialog
import com.cmx.wanhui.view.ConfirmDialog.*
import com.google.zxing.integration.android.IntentIntegrator
import com.lsxiao.apollo.core.Apollo
import com.lsxiao.apollo.core.annotations.Receive
import kotlinx.android.synthetic.main.activity_main.nav_view

class MainActivity : BaseActivity() {
    private var navController: NavController? = null

    @RequiresApi(api = Build.VERSION_CODES.M)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)
        navController = Navigation.findNavController(this, R.id.nav_host_fragment_activity_main)
        NavigationUI.setupWithNavController(nav_view, navController!!)
        nav_view.itemIconTintList = null
        JPushInterface.setAlias(this, 1, SpUtils.getString(this, "sign"))
    }


    /**
     * 显示tabbar
     */
    @Receive(Events.JS_OPEN_TABBAR_SHOW)
    fun showTab() {
        nav_view.visibility = View.VISIBLE
    }


    /**
     * 隐藏tabbar
     */
    @Receive(Events.JS_OPEN_TABBAR_HIDE)
    fun hideTab() {
        nav_view.visibility = View.GONE
    }

    /**
     * 打开新的web
     */
    @Receive(Events.JS_OPEN_OPEN_WEB)
    fun openWeb(url: String?) {
        val intent = Intent(this, WebActivity::class.java)
        intent.putExtra("url", url)
        startActivity(intent)
    }

    /**
     * 选择tab
     */
    @Receive(Events.JS_OPEN_TAB)
    fun ckTab(mode: String?) {
        Apollo.emit(Events.JS_OPEN_CLOSE_WEB)
        when (mode) {
            "1" -> {
                val menu = nav_view!!.menu
                val menuItem = menu.getItem(0) // 将index替换为您想要点击的项目的索引
                menuItem.isChecked = true
                navController!!.navigate(R.id.navigation_home)
            }

            "2" -> {
                val menu2 = nav_view!!.menu
                val menuItem2 = menu2.getItem(1) // 将index替换为您想要点击的项目的索引
                menuItem2.isChecked = true
                navController!!.navigate(R.id.navigation_dashboard)
            }

            "3" -> {
                val menu3 = nav_view!!.menu
                val menuItem3 = menu3.getItem(2) // 将index替换为您想要点击的项目的索引
                menuItem3.isChecked = true
                navController!!.navigate(R.id.navigation_notifications)
            }
        }
    }


    /**
     * 退出登录
     */
    @Receive(Events.JS_OPEN_LOGOUT)
    fun exit() {
        Apollo.emit(Events.JS_OPEN_CLOSE_WEB)
        finish()
        val intent = Intent(this, LoginActivity::class.java)
        startActivity(intent)
    }


    /**
     * 二维码扫描
     */
    @Receive(Events.JS_OPEN_SCANQR)
    fun scanQR() {
        val integrator = IntentIntegrator(this)
        integrator.setOrientationLocked(true) // 设置扫描方向是否锁定
        integrator.captureActivity = CustomCaptureActivity::class.java
        integrator.setPrompt("请对准二维码") // 设置提示语
        integrator.initiateScan()
    }


    // 处理扫描结果
    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        val result = IntentIntegrator.parseActivityResult(requestCode, resultCode, data)
        if (result != null) {
            if (result.contents == null) {   // 扫描取消
            } else {    // 扫描成功，处理结果
                val scannedData = result.contents
                Apollo.emit(Events.JS_OPEN_SCANQR_BACK, scannedData)
            }
        } else {
            super.onActivityResult(requestCode, resultCode, data)
        }
    }


    override fun onBackPressed() {
        Apollo.emit(Events.JS_OPEN_WEB_BACK)
    }

    @Receive(Events.JS_OPEN_WEB_BACK_EXIT)
    fun exitApp() {
        ConfirmDialog(this, object : IBack {
            override fun confirmBack() {
                finish()
            }

            override fun cancelBack() {
            }
        }).show()
    }

}