package com.cmx.wanhui.ui;


import android.app.Activity;
import android.content.ClipData;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebView;

import androidx.annotation.NonNull;

import com.cmx.wanhui.constant.Events;
import com.cmx.wanhui.databinding.FragmentHomeBinding;
import com.cmx.wanhui.model.QRBean;
import com.cmx.wanhui.utils.L;
import com.google.gson.Gson;
import com.lsxiao.apollo.core.Apollo;
import com.lsxiao.apollo.core.annotations.Receive;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;

public class HomeFragment extends BaseFragment {

    private FragmentHomeBinding binding;
    private WebView mWebView;
    private ValueCallback<Uri[]> mUploadMessage;
    private String mCameraPhotoPath = null;
    private long size = 0;
    private static final int INPUT_FILE_REQUEST_CODE = 1;


    public View onCreateView(@NonNull LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        binding = FragmentHomeBinding.inflate(inflater, container, false);
        View root = binding.getRoot();
        mWebView = binding.wvHome;
        setWebView(mWebView);
        mWebView.loadUrl(Events.WEB_HOME_URL);
        mWebView.setWebChromeClient(new PQChromeClient());
        return root;
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }


    public class PQChromeClient extends WebChromeClient {
        // For Android 5.0+
        public boolean onShowFileChooser(WebView view, ValueCallback<Uri[]> filePath, WebChromeClient.FileChooserParams fileChooserParams) {
            // Double check that we don't have any existing callbacks
            if (mUploadMessage != null) {
                mUploadMessage.onReceiveValue(null);
            }
            mUploadMessage = filePath;
            Log.e("FileCooserParams => ", filePath.toString());
            Intent takePictureIntent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
            if (takePictureIntent.resolveActivity(getActivity().getPackageManager()) != null) {
                // Create the File where the photo should go
                File photoFile = null;
                try {
                    photoFile = createImageFile();
                    takePictureIntent.putExtra("PhotoPath", mCameraPhotoPath);
                } catch (IOException ex) {
                    // Error occurred while creating the File
                    Log.e("test", "Unable to create Image File", ex);
                }

                // Continue only if the File was successfully created
                if (photoFile != null) {
                    mCameraPhotoPath = "file:" + photoFile.getAbsolutePath();
                    takePictureIntent.putExtra(MediaStore.EXTRA_OUTPUT, Uri.fromFile(photoFile));
                } else {
                    takePictureIntent = null;
                }
            }

            Intent contentSelectionIntent = new Intent(Intent.ACTION_GET_CONTENT);
            contentSelectionIntent.addCategory(Intent.CATEGORY_OPENABLE);
            contentSelectionIntent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true);
            contentSelectionIntent.setType("image/*");
            Intent[] intentArray;
            if (takePictureIntent != null) {
                intentArray = new Intent[]{takePictureIntent};
            } else {
                intentArray = new Intent[2];
            }
            Intent chooserIntent = new Intent(Intent.ACTION_CHOOSER);
            chooserIntent.putExtra(Intent.EXTRA_INTENT, contentSelectionIntent);
            chooserIntent.putExtra(Intent.EXTRA_TITLE, "Image Chooser");
            chooserIntent.putExtra(Intent.EXTRA_INITIAL_INTENTS, intentArray);
            startActivityForResult(Intent.createChooser(chooserIntent, "Select images"), 1);
            return true;
        }
    }


    private File createImageFile() throws IOException {
        // Create an image file name
        String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
        String imageFileName = "JPEG_" + timeStamp + "_";
        File storageDir = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES);
        File imageFile = File.createTempFile(imageFileName,  /* prefix */
                ".jpg",         /* suffix */
                storageDir      /* directory */);
        return imageFile;
    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode != INPUT_FILE_REQUEST_CODE || mUploadMessage == null) {
            super.onActivityResult(requestCode, resultCode, data);
            return;
        }
        try {
            String file_path = mCameraPhotoPath.replace("file:", "");
            File file = new File(file_path);
            size = file.length();
            if (data != null || mCameraPhotoPath != null) {
                Integer count = 1;
                ClipData images = null;
                try {
                    images = data.getClipData();
                } catch (Exception e) {
                    Log.e("Error!", e.getLocalizedMessage());
                }

                if (images == null && data != null && data.getDataString() != null) {
                    count = data.getDataString().length();
                } else if (images != null) {
                    count = images.getItemCount();
                }
                Uri[] results = new Uri[count];
                // Check that the response is a good one
                if (resultCode == Activity.RESULT_OK) {
                    if (size != 0) {
                        // If there is not data, then we may have taken a photo
                        if (mCameraPhotoPath != null) {
                            results = new Uri[]{Uri.parse(mCameraPhotoPath)};
                        }
                    } else if (data.getClipData() == null) {
                        results = new Uri[]{Uri.parse(data.getDataString())};
                    } else {

                        for (int i = 0; i < images.getItemCount(); i++) {
                            results[i] = images.getItemAt(i).getUri();
                        }
                    }
                }
                mUploadMessage.onReceiveValue(results);
                mUploadMessage = null;
            }
        } catch (Exception e) {
            Log.e("Error!", "Error while opening image file" + e.getLocalizedMessage());
        }
    }


    /**
     * 二维码扫描返回
     */
    @Receive(Events.JS_OPEN_SCANQR_BACK)
    public void onQRBack(String msg) {
        QRBean mQRBean = new QRBean();
        mQRBean.setMsg(msg);
        String ms = new Gson().toJson(mQRBean);
        String jsString = "javascript:window.onQRBack(" + ms + ")";
        L.e("JS二维码扫描返回>>>>", ms + "<<>>" + jsString);
        mWebView.evaluateJavascript(jsString, new ValueCallback<String>() {
            @Override
            public void onReceiveValue(String s) {
            }
        });
    }


    /**
     * web返回
     */
    @Receive(Events.JS_OPEN_WEB_BACK)
    public void webBack() {
        if (mWebView.canGoBack()) {
            mWebView.goBack();
        } else {
            Apollo.emit(Events.JS_OPEN_WEB_BACK_EXIT);
        }
    }

}