package com.cmx.wanhui.utils

import android.app.Activity
import android.content.Context
import android.graphics.Color
import android.os.Build
import android.os.Environment
import android.os.StatFs
import android.util.Log
import android.view.View
import android.view.WindowManager
import java.io.BufferedReader
import java.io.File
import java.io.FileReader
import java.io.IOException
import java.nio.charset.StandardCharsets
import java.security.MessageDigest
import java.security.NoSuchAlgorithmException
import java.util.Locale

object MyUtils {
    private val TAG = "cmx_" + MyUtils::class.java.simpleName
    fun setNavigationStatusColor(activity: Activity, color: Int) {
        activity.window.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS)
        activity.window.navigationBarColor = color
        activity.window.statusBarColor = color
    }

    @JvmStatic
    fun setFullscreen(activity: Activity, isShowStatusBar: Boolean, isShowNavigationBar: Boolean) {
        var uiOptions =
            View.SYSTEM_UI_FLAG_LAYOUT_STABLE or View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION or View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN or View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY
        if (!isShowStatusBar) {
            uiOptions = uiOptions or View.SYSTEM_UI_FLAG_FULLSCREEN
        }
        if (!isShowNavigationBar) {
            uiOptions = uiOptions or View.SYSTEM_UI_FLAG_HIDE_NAVIGATION
        }
        activity.window.decorView.systemUiVisibility = uiOptions
        setNavigationStatusColor(activity, Color.TRANSPARENT)
    }

    @JvmStatic
    fun setAndroidNativeLightStatusBar(activity: Activity, dark: Boolean) {
        val decor = activity.window.decorView
        if (dark) {
            decor.systemUiVisibility =
                View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN or View.SYSTEM_UI_FLAG_LIGHT_STATUS_BAR
        } else {
            decor.systemUiVisibility = View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN or View.SYSTEM_UI_FLAG_LAYOUT_STABLE
        }
    }

    @Throws(Exception::class)
    private fun getVersionName(activity: Activity): String {
        val packageManager = activity.packageManager
        // getPackageName()是你当前类的包名，0代表是获取版本信息
        val packInfo = packageManager.getPackageInfo(activity.packageName, 0)
        return packInfo.versionName
    }

    @Throws(Exception::class)
    fun getDeviceInfo(activity: Activity) {
        val model = Build.MODEL
        val carrier = Build.MANUFACTURER
        val version = getVersionName(activity)
        val lang = systemLanguage
        val brand = phoneBrand
        val releaseVersion = versionRelease
        val sdkVersion = sdkVersion
        Log.e(
            TAG,
            "model=$model, carrier=$carrier, version=$version, lang=$lang, brand=$brand, releaseVersion=$releaseVersion,sdk version=$sdkVersion"
        )
    }

    val systemLanguage: String
        get() = Locale.getDefault().language
    val systemLanguageList: Array<Locale>
        get() = Locale.getAvailableLocales()
    val phoneBrand: String
        get() = Build.BRAND
    val versionRelease: String
        get() = Build.VERSION.RELEASE
    val sdkVersion: Int
        get() = Build.VERSION.SDK_INT//8.0-//8.0+

    //9.0+
    val serialNum: String?
        get() {
            var serial: String? = "unknown"
            try {
                serial = if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) { //9.0+
                    Build.getSerial()
                } else if (Build.VERSION.SDK_INT > Build.VERSION_CODES.N) { //8.0+
                    Build.SERIAL
                } else { //8.0-
                    val c = Class.forName("android.os.SystemProperties")
                    val get = c.getMethod("get", String::class.java)
                    get.invoke(c, "ro.serialno") as String
                }
            } catch (e: Exception) {
                Log.e("序列号》》", e.toString())
                e.printStackTrace()
            }
            Log.e("序列号》》", serial!!)
            return serial
        }

    fun createTempImageFile(context: Context?): File? {
        val destFolder = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DCIM)
        destFolder.mkdirs()
        val dateTimeString = System.currentTimeMillis().toString() + ""
        var imageFile: File? = null
        imageFile = try {
            File.createTempFile("$dateTimeString-", ".jpg", destFolder)
        } catch (e: IOException) {
            Log.e("文件失败>>>", e.toString())
            throw RuntimeException(e)
        }
        return imageFile
    }

    val totalRam: String
        get() {
            val path = "/proc/meminfo"
            var ramMemorySize: String? = null
            var totalRam = 0
            try {
                val fileReader = FileReader(path)
                val br = BufferedReader(fileReader, 4096)
                ramMemorySize = br.readLine().split("\\s+".toRegex()).dropLastWhile { it.isEmpty() }.toTypedArray()[1]
                br.close()
            } catch (e: Exception) {
                e.printStackTrace()
            }
            if (ramMemorySize != null) {
                totalRam = Math.ceil(java.lang.Float.valueOf(ramMemorySize.toFloat() / (1024 * 1024)).toDouble()).toInt()
            }
            return totalRam.toString() + ""
        }
    val totalRom: String
        get() {
            val dataDir = Environment.getDataDirectory()
            val stat = StatFs(dataDir.path)
            val blockSize = stat.blockSizeLong
            val totalBlocks = stat.blockCountLong
            val size = totalBlocks * blockSize
            val GB = (1024 * 1024 * 1024).toLong()
            val deviceRomMemoryMap =
                longArrayOf(2 * GB, 4 * GB, 8 * GB, 16 * GB, 32 * GB, 64 * GB, 128 * GB, 256 * GB, 512 * GB, 1024 * GB, 2048 * GB)
            val displayRomSize =
                arrayOf("2GB", "4GB", "8GB", "16GB", "32GB", "64GB", "128GB", "256GB", "512GB", "1024GB", "2048GB")
            var i: Int
            i = 0
            while (i < deviceRomMemoryMap.size) {
                if (size <= deviceRomMemoryMap[i]) {
                    break
                }
                if (i == deviceRomMemoryMap.size) {
                    i--
                }
                i++
            }
            return displayRomSize[i].replace("GB", "")
        }

    /**
     * sha256加密
     *
     * @param str 要加密的字符串
     * @return 加密后的字符串
     */
    fun getSha256Str(str: String): String {
        val messageDigest: MessageDigest
        var encodeStr = ""
        try {
            messageDigest = MessageDigest.getInstance("SHA-256")
            messageDigest.update(str.toByteArray(StandardCharsets.UTF_8))
            encodeStr = byte2Hex(messageDigest.digest())
        } catch (e: NoSuchAlgorithmException) {
            e.printStackTrace()
        }
        return encodeStr
    }

    /**
     * sha256加密 将byte转为16进制
     *
     * @param bytes 字节码
     * @return 加密后的字符串
     */
    private fun byte2Hex(bytes: ByteArray): String {
        val stringBuilder = StringBuilder()
        var temp: String
        for (aByte in bytes) {
            temp = Integer.toHexString(aByte.toInt() and 0xFF)
            if (temp.length == 1) {
                //1得到一位的进行补0操作
                stringBuilder.append("0")
            }
            stringBuilder.append(temp)
        }
        return stringBuilder.toString()
    }
}